@@ -21,12 +21,13 @@
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-**************************************************************************/
+ **************************************************************************/
 
 package org.omegat.filters3.xml.docbook;
 
 import java.io.BufferedReader;
 import java.util.regex.Matcher;
+
 import org.omegat.filters2.Instance;
 import org.omegat.filters3.xml.XMLDialect;
 import org.omegat.filters3.xml.XMLFilter;
@@ -35,19 +36,17 @@ import org.omegat.util.OStrings;
 
 /**
  * Filter for DocBook files.
- *
+ * 
  * @author Maxym Mykhalchuk
  * @author Fabian Mandelbaum
  * @author Didier Briel
  */
-public class DocBookFilter extends XMLFilter
-{
-    
+public class DocBookFilter extends XMLFilter {
+
     /**
      * Creates a new instance of DocBookFilter
      */
-    public DocBookFilter()
-    {
+    public DocBookFilter() {
         super(new DocBookDialect());
     }
 
@@ -56,63 +55,57 @@ public class DocBookFilter extends XMLFilter
      * 
      * @return File format name
      */
-    public String getFileFormatName()
-    {
+    public String getFileFormatName() {
         return OStrings.getString("DocBook_FILTER_NAME");
     }
 
     /**
-     * Returns the hint displayed while the user edits the filter,
-     * and when she adds/edits the instance of this filter.
-     * The hint may be any string, preferably in a non-geek language.
+     * Returns the hint displayed while the user edits the filter, and when she
+     * adds/edits the instance of this filter. The hint may be any string,
+     * preferably in a non-geek language.
      * 
      * 
      * @return The hint for editing the filter in a non-geek language.
      */
-    public String getHint()
-    {
-        return OStrings.getString("DocBook_HINT"); 
+    public String getHint() {
+        return OStrings.getString("DocBook_HINT");
     }
 
     /**
-     * The default list of filter instances that this filter class has.
-     * One filter class may have different filter instances, different
-     * by source file mask, encoding of the source file etc.
+     * The default list of filter instances that this filter class has. One
+     * filter class may have different filter instances, different by source
+     * file mask, encoding of the source file etc.
      * <p>
      * Note that the user may change the instances freely.
      * 
      * @return Default filter instances
      */
-    public Instance[] getDefaultInstances()
-    {
-        return new Instance[] 
-        {
-            new Instance("*.xml", null, null),                            
-            new Instance("*.dbk", null, null),                            
-        };
+    public Instance[] getDefaultInstances() {
+        return new Instance[] { new Instance("*.xml", null, null), new Instance("*.dbk", null, null), };
     }
 
     /**
      * Either the encoding can be read, or it is UTF-8..
+     * 
      * @return <code>false</code>
      */
-    public boolean isSourceEncodingVariable()
-    {
+    public boolean isSourceEncodingVariable() {
         return false;
     }
-    
+
     /**
      * Yes, DocBook may be written out in a variety of encodings.
+     * 
      * @return <code>true</code>
      */
-    public boolean isTargetEncodingVariable()
-    {
+    public boolean isTargetEncodingVariable() {
         return true;
     }
-    
-    /** 
-     * Returns whether the file is supported by the filter, by checking 
-     * DB4 (DTD) or DB5 (Namespace) constraints.
+
+    /**
+     * Returns whether the file is supported by the filter, by checking DB4
+     * (DTD) or DB5 (Namespace) constraints.
+     * 
      * @return <code>true</code> or <code>false</code>
      */
     public boolean isFileSupported(BufferedReader reader) {
@@ -126,14 +119,12 @@ public class DocBookFilter extends XMLFilter
             Matcher matcher = DocBookDialect.DOCBOOK_PUBLIC_DTD.matcher(buf);
             if (matcher.find()) { // We can safely assume we have a db4 doc...
                 return true;
-            }
-            else { // Let's see if we have a db5 doc...
+            } else { // Let's see if we have a db5 doc...
                 matcher = DocBookDialect.DB5_XMLNS.matcher(buf);
                 if (!matcher.find()) // Neither db4, nor db5
                     return false;
             }
-        }
-        catch (Exception e) {
+        } catch (Exception e) {
             return false;
         }
         return true;
